@@ -1,9 +1,10 @@
 package Test::RDF;
 
+use 5.006;
 use warnings;
 use strict;
 
-use Carp;
+use Carp qw(confess);
 use RDF::Trine;
 use RDF::Trine::Parser;
 use RDF::Trine::Model;
@@ -11,7 +12,7 @@ use RDF::Trine::Graph;
 use Scalar::Util qw/blessed/;
 
 use base 'Test::Builder::Module';
-our @EXPORT = qw/are_subgraphs is_rdf is_valid_rdf isomorph_graphs has_subject has_predicate has_object_uri has_uri hasnt_uri has_literal hasnt_literal pattern_target pattern_ok pattern_fail/;
+our @EXPORT = qw/are_subgraphs is_rdf is_valid_rdf isomorph_graphs has_subject has_predicate has_object_uri has_type has_uri hasnt_uri has_literal hasnt_literal pattern_target pattern_ok pattern_fail/;
 
 
 =head1 NAME
@@ -20,11 +21,11 @@ Test::RDF - Test RDF data for content, validity and equality, etc.
 
 =head1 VERSION
 
-Version 1.15_2
+Version 1.21_01
 
 =cut
 
-our $VERSION = '1.15_2';
+our $VERSION = '1.21_01';
 
 
 =head1 SYNOPSIS
@@ -40,6 +41,7 @@ our $VERSION = '1.15_2';
  has_subject($uri_string, $model, 'Subject URI is found');
  has_predicate($uri_string, $model, 'Predicate URI is found');
  has_object_uri($uri_string, $model, 'Object URI is found');
+ has_type($uri_string, $model, 'Class URI is found');
  has_literal($string, $language, $datatype, $model, 'Literal is found');
  hasnt_literal($string, $language, $datatype, $model, 'Literal is not found');
  pattern_target($model);
@@ -134,6 +136,8 @@ Use to check if the input RDF::Trine::Models have isomorphic graphs.
 
 sub isomorph_graphs {
   my ($model1, $model2, $name) = @_;
+  confess 'No valid models given in test' unless ((blessed($model1) && $model1->isa('RDF::Trine::Model'))
+																	&& (blessed($model2) && $model2->isa('RDF::Trine::Model')));
   my $g1 = RDF::Trine::Graph->new( $model1 );
   my $g2 = RDF::Trine::Graph->new( $model2 );
   my $test = __PACKAGE__->builder;
@@ -157,6 +161,8 @@ Use to check if the first RDF::Trine::Models is a subgraph of the second.
 
 sub are_subgraphs {
   my ($model1, $model2, $name) = @_;
+  confess 'No valid models given in test' unless ((blessed($model1) && $model1->isa('RDF::Trine::Model'))
+																	&& (blessed($model2) && $model2->isa('RDF::Trine::Model')));
   my $g1 = RDF::Trine::Graph->new( $model1 );
   my $g2 = RDF::Trine::Graph->new( $model2 );
   my $test = __PACKAGE__->builder;
@@ -181,6 +187,7 @@ of the statements given in the model given as second argument.
 
 sub has_subject {
   my ($uri, $model, $name) = @_;
+  confess 'No valid model given in test' unless (blessed($model) && $model->isa('RDF::Trine::Model'));
   my $resource = _resource_uri_checked($uri, $name);
   return $resource unless ($resource);
   my $count = $model->count_statements($resource, undef, undef);
@@ -197,6 +204,7 @@ of the statements given in the model given as second argument.
 
 sub has_predicate {
   my ($uri, $model, $name) = @_;
+  confess 'No valid model given in test' unless (blessed($model) && $model->isa('RDF::Trine::Model'));
   my $resource = _resource_uri_checked($uri, $name);
   return $resource unless ($resource);
   my $count = $model->count_statements(undef, $resource, undef);
@@ -212,12 +220,33 @@ of the statements given in the model given as second argument.
 
 sub has_object_uri {
   my ($uri, $model, $name) = @_;
+  confess 'No valid model given in test' unless (blessed($model) && $model->isa('RDF::Trine::Model'));
   my $resource = _resource_uri_checked($uri, $name);
   return $resource unless ($resource);
   my $count = $model->count_statements(undef, undef, $resource);
   return _single_uri_tests($count, $name);
 }
 
+
+=head2 has_type
+
+Check if the string URI passed as first argument is an RDF class
+instance in any of the statements given in the model given as second
+argument.
+
+=cut
+
+sub has_type {
+  my ($uri, $model, $name) = @_;
+  confess 'No valid model given in test' unless (blessed($model) && $model->isa('RDF::Trine::Model'));
+  my $resource = _resource_uri_checked($uri, $name);
+  return $resource unless ($resource);
+  my $count = $model->count_statements(undef,
+													RDF::Trine::Node::Resource->new('http://www.w3.org/1999/02/22-rdf-syntax-ns#type'),
+													$resource);
+  return _single_uri_tests($count, $name);
+}
+
 =head2 has_literal
 
 Check if the string passed as first argument, with corresponding
@@ -243,6 +272,7 @@ and a language literal like
 
 sub has_literal {
   my ($string, $lang, $datatype, $model, $name) = @_;
+  confess 'No valid model given in test' unless (blessed($model) && $model->isa('RDF::Trine::Model'));
   my $literal;
   my $test = __PACKAGE__->builder;
   eval {
@@ -275,6 +305,7 @@ invalid, however.
 
 sub hasnt_literal {
   my ($string, $lang, $datatype, $model, $name) = @_;
+  confess 'No valid model given in test' unless (blessed($model) && $model->isa('RDF::Trine::Model'));
   my $literal;
   my $test = __PACKAGE__->builder;
   eval {
@@ -308,6 +339,7 @@ the statements given in the model given as second argument.
 
 sub has_uri {
   my ($uri, $model, $name) = @_;
+  confess 'No valid model given in test' unless (blessed($model) && $model->isa('RDF::Trine::Model'));
   my $test = __PACKAGE__->builder;
   my $resource = _resource_uri_checked($uri, $name);
   return $resource unless ($resource);
@@ -333,6 +365,7 @@ of the statements given in the model given as second argument.
 
 sub hasnt_uri {
   my ($uri, $model, $name) = @_;
+  confess 'No valid model given in test' unless (blessed($model) && $model->isa('RDF::Trine::Model'));
   my $test = __PACKAGE__->builder;
   my $resource;
   eval {
@@ -579,7 +612,8 @@ Toby Inkster has submitted the pattern_* functions.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010 ABC Startsiden AS and 2010-2013 Kjetil Kjernsmo.
+Copyright 2010 ABC Startsiden AS.
+Copyright 2010, 2011, 2012, 2013, 2014, 2015, 2017 Kjetil Kjernsmo.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
